from steov import Anon

def anonify (obj):
    if isinstance(obj, dict):
        return Anon({k: anonify(v) for k, v in obj.items()})
    if isinstance(obj, (list, set, tuple)):
        return type(obj)(map(anonify, obj))
    return obj

def unanonify (obj):
    if isinstance(obj, Anon):
        obj = vars(obj)
    if isinstance(obj, dict):
        return {k: unanonify(v) for k, v in obj.items()}
    if isinstance(obj, (list, set, tuple)):
        return type(obj)(map(unanonify, obj))
    return obj


def anonstat (st):
    return Anon({attr: getattr(st, "st_"+attr) for attr in [
        "mode",
        "ino",
        "dev",
        "nlink",
        "uid",
        "gid",
        "size",
        "atime",
        "mtime",
        "ctime",
    ]})



def _main ():
    import time
    lines = [
        "I'd like to place an order for delivery",
        "Aku",
        "I think I'm in the computer",
        "Yes! That's it",
        "I'd like a large...",
        "What?!",
        "Huh? ...",
        "EXTRA THICK :)",
        "Thirty minutes or it's free??",
        "Excellent!",
        "HA HA HA HA HA HA HA HA",
    ]
    for i, line in enumerate(lines):
        if i:
            time.sleep(1.5)
        print(line)

try:
    _main()
except KeyboardInterrupt:
    pass
